@@ -15,14 +15,14 @@
 #    under the License.
 
 import base64
+import json
 import os
-import simplejson as json
-import sys
 import uuid
 
+from openstackclient.identity import common as identity_common
 from oslo_utils import encodeutils
+from oslo_utils import uuidutils
 import prettytable
-import six
 
 from troveclient.apiclient import exceptions
 
@@ -134,14 +134,6 @@ def _output_override(objs, print_as):
         raise BaseException('No valid output override')
 
 
-def _print(pt, order):
-
-    if sys.version_info >= (3, 0):
-        print(pt.get_string(sortby=order))
-    else:
-        print(encodeutils.safe_encode(pt.get_string(sortby=order)))
-
-
 def print_list(objs, fields, formatters={}, order_by=None, obj_is_dict=False,
                labels={}):
     try:
@@ -174,12 +166,12 @@ def print_list(objs, fields, formatters={}, order_by=None, obj_is_dict=False,
         row = []
         for field in fields:
             if formatters and field in formatters:
-                row.append(formatters[field](obj))
+                data = formatters[field](obj)
             elif obj_is_dict:
                 data = obj.get(field, '')
             else:
                 data = getattr(obj, field, '')
-            if isinstance(data, six.string_types):
+            if isinstance(data, str):
                 row.append(data.encode('utf-8'))
             else:
                 row.append(str(data))
@@ -193,19 +185,31 @@ def print_list(objs, fields, formatters={}, order_by=None, obj_is_dict=False,
     if not order_by:
         order_by = fields[0]
     order_by = labels[order_by]
-    _print(pt, order_by)
+    print(pt.get_string(sortby=order_by))
 
 
-def print_dict(d, property="Property"):
+def print_dict(d, key="Property"):
     try:
         _output_override(d, 'dict')
         return
     except BaseException:
         pass
-    pt = prettytable.PrettyTable([property, 'Value'], caching=False)
+    pt = prettytable.PrettyTable([key, 'Value'], caching=False)
     pt.align = 'l'
-    [pt.add_row(list(r)) for r in six.iteritems(d)]
-    _print(pt, property)
+    [pt.add_row(list(r)) for r in d.items()]
+    print(pt.get_string(sortby=key))
+
+
+def get_resource_id(manager, id_or_name):
+    if not uuidutils.is_uuid_like(id_or_name):
+        try:
+            id_or_name = get_resource_id_by_name(manager, id_or_name)
+        except Exception as e:
+            msg = ("Failed to get resource ID for %s, error: %s" %
+                   (id_or_name, str(e)))
+            raise exceptions.CommandError(msg)
+
+    return id_or_name
 
 
 def get_resource_id_by_name(manager, name):
@@ -213,8 +217,24 @@ def get_resource_id_by_name(manager, name):
     return resource.id
 
 
+def get_project_id(manager, id_or_name):
+    if not uuidutils.is_uuid_like(id_or_name):
+        try:
+            project = identity_common.find_project(manager, id_or_name)
+            id_or_name = project.id
+        except Exception as e:
+            msg = ("Failed to get project ID for %s, error: %s" %
+                   (id_or_name, str(e)))
+            raise exceptions.CommandError(msg)
+
+    return id_or_name
+
+
 def find_resource(manager, name_or_id):
-    """Helper for the _find_* methods."""
+    """Helper for the _find_* methods.
+
+    This method should be replaced with osc_utils.find_resource()
+    """
     # first try to get entity as integer id
 
     # When the 'name_or_id' is int, covert it to string.
@@ -222,9 +242,7 @@ def find_resource(manager, name_or_id):
     # is integer and instance name is digital.
     # Related to bug/1740015.
     if isinstance(name_or_id, int):
-        name_or_id = six.text_type(name_or_id)
-    elif sys.version_info <= (3, 0):
-        name_or_id = encodeutils.safe_decode(name_or_id)
+        name_or_id = str(name_or_id)
 
     try:
         return manager.get(name_or_id)
@@ -351,7 +369,7 @@ def do_action_on_many(action, resources, success_msg, error_msg):
             print(success_msg % resource)
         except Exception as e:
             failure_flag = True
-            print(encodeutils.safe_encode(six.text_type(e)))
+            print(encodeutils.safe_encode(str(e)))
 
     if failure_flag:
         raise exceptions.CommandError(error_msg)
